==> webkit2gtk_2.50.3.orig.tar.xz: webkitgtk-2.50.3/Source/WebCore/testing/EventTargetForTesting.cpp <==
/*
 * Copyright (C) 2025 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "EventTargetForTesting.h"

#include "ContextDestructionObserverInlines.h"
#include "CustomEvent.h"
#include "MessageForTesting.h"
#include "MessageTargetForTesting.h"
#include <wtf/TZoneMallocInlines.h>

namespace WebCore {

WTF_MAKE_TZONE_OR_ISO_ALLOCATED_IMPL(EventTargetForTesting);

Ref<EventTargetForTesting> EventTargetForTesting::create(ScriptExecutionContext& context, MessageTargetForTesting& target)
{
    return *new EventTargetForTesting(context, target);
}

EventTargetForTesting::EventTargetForTesting(ScriptExecutionContext& context, MessageTargetForTesting& target)
    : ActiveDOMObject { &context }
    , m_messageTarget { target }
{
    target.addMessageClientForTesting(*this);
}

EventTargetForTesting::~EventTargetForTesting()
{
    if (RefPtr messageTarget = m_messageTarget.get())
        messageTarget->removeMessageClientForTesting(*this);
}

void EventTargetForTesting::sendInternalMessage(const MessageForTesting& message)
{
    RefPtr scriptExecutionContext = this->scriptExecutionContext();
    if (!scriptExecutionContext)
        return;

    JSC::JSValue detail = jsNontrivialString(scriptExecutionContext->vm(), message.data);

    dispatchEvent(CustomEvent::create(message.type, CustomEvent::Init {
        { },
        detail,
    }));
}

}

==> webkit2gtk_2.51.1.orig.tar.xz: webkitgtk-2.51.1/Source/WebCore/testing/EventTargetForTesting.cpp <==
/*
 * Copyright (C) 2025 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "EventTargetForTesting.h"

#include "ContextDestructionObserverInlines.h"
#include "CustomEvent.h"
#include "MessageForTesting.h"
#include "MessageTargetForTesting.h"
#include <wtf/TZoneMallocInlines.h>

namespace WebCore {

WTF_MAKE_TZONE_OR_ISO_ALLOCATED_IMPL(EventTargetForTesting);

Ref<EventTargetForTesting> EventTargetForTesting::create(ScriptExecutionContext& context, MessageTargetForTesting& target)
{
    return *new EventTargetForTesting(context, target);
}

EventTargetForTesting::EventTargetForTesting(ScriptExecutionContext& context, MessageTargetForTesting& target)
    : ActiveDOMObject { &context }
    , m_messageTarget { target }
{
    target.addMessageClientForTesting(*this);
}

EventTargetForTesting::~EventTargetForTesting()
{
    if (RefPtr messageTarget = m_messageTarget.get())
        messageTarget->removeMessageClientForTesting(*this);
}

void EventTargetForTesting::sendInternalMessage(const MessageForTesting& message)
{
    RefPtr scriptExecutionContext = this->scriptExecutionContext();
    if (!scriptExecutionContext)
        return;

    JSC::JSValue detail = jsNontrivialString(scriptExecutionContext->vm(), message.data);

    dispatchEvent(CustomEvent::create(message.type, CustomEvent::Init {
        { },
        detail,
    }));
}

ScriptExecutionContext* EventTargetForTesting::scriptExecutionContext() const
{
    return ActiveDOMObject::scriptExecutionContext();
}

}
